<?php $TRANSLATIONS = array(
"OpenID Changed" => "se cambió el OpenID",
"Invalid request" => "Pedido no válido",
"This is an OpenID server endpoint. For more information, see " => "Este es un servidor OpenID del tipo endpoint. Para más información, mirá ",
"Identity: <b>" => "Identidad: <b>",
"Realm: <b>" => "Realm: <b>",
"User: <b>" => "Usuario: <b>",
"Login" => "Usuario",
"Error: <b>No user Selected" => "Error: <b> No hay ningún usuario seleccionado",
"OpenID" => "OpenID",
"you can authenticate to other sites with this address" => "podés autenticarte en otros sitios con esta dirección",
"Authorized OpenID provider" => "Poveedor autorizado de OpenID",
"Your address at Wordpress, Identi.ca, &hellip;" => "Tu dirección en Wordpress, Identi.ca, &hellip;"
);
